StatusBox class
- Inheritance
-
- Object
- BaseComponent
- StatusBox
Constructors
- StatusBox({required String message, required StatusType status, String? customIcon, Style? messageStyle})
-
const
Properties
- customIcon → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
final
- messageStyle → Style?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → StatusType
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
render(
) → String -
Render the component to a string
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited